@@ -2,11 +2,12 @@ from abc import ABCMeta, abstractmethod
 
 from jinja2 import *
 
-from .app import App, _MainApp
+from .app import App
 from .builder import Builder
 from .hook import HookRegistry
 from .http import Request
 from .registry import AppRegistry
+from .project import Project
 from .router import Router
 
 
