@@ -4,19 +4,20 @@
     * mitama.json置くだけのコマンド
 
 """
-import json
 import os
+import shutil
+import glob
 from pathlib import Path
 
 from mitama.conf import Config
 
 
 def init_project_dir(path):
-    with open(path / "mitama.json", mode="w") as f:
-        conf = Config(path, {"apps": {"mitama.portal": {"path": "/"}}})
-        data = conf.to_dict()
-        json_text = json.dumps(data, indent=2)
-        f.write(json_text)
+    files = glob.glob(os.path.dirname(__file__) + "/../skeleton/project/*")
+    for file in files:
+        if os.path.isdir(file):
+            continue
+        shutil.copy(file, path, follow_symlinks=False)
 
 
 class Command:
