@@ -13,7 +13,17 @@ from pathlib import Path
 class Config:
     def __init__(self, path, dic):
         self._project_dir = path
-        self._sqlite_db_path = Path(self._project_dir) / "db.sqlite3"
+        self.database = {
+            "type": "sqlite",
+            "path": Path(self._project_dir) / "db.sqlite3"
+        }
+        self.password_validation = {}
+        self.port = 8080
+        self.mail = {
+            "host": "localhost",
+            "port": 25,
+            "address": "mitama@example.com"
+        }
         for k in dic:
             try:
                 setattr(self, k, dic[k])
