@@ -6,18 +6,23 @@ Databaseはシングルトンの接続のインスタンスを生成するクラ
 各アプリにはDatabaseを継承したクラスを定義してもらい、そいつのModelプロパティのベースクラスからモデルを作ってもらいます。
 """
 
-import inspect
+import inspect as _inspect
 
-from sqlalchemy import and_, asc, desc, or_, orm
+from sqlalchemy import *
+from sqlalchemy.engine import *
+from sqlalchemy.schema import *
+from sqlalchemy.inspection import inspect
+from sqlalchemy.sql import *
+from sqlalchemy.types import *
+from sqlalchemy.orm import *
 from sqlalchemy.ext.declarative import declarative_base
 from sqlalchemy.ext.declarative.api import DeclarativeMeta
-from sqlalchemy.orm import scoped_session, sessionmaker
 from sqlalchemy.orm.exc import UnmappedClassError
 from sqlalchemy.sql import func
 
 from mitama._extra import _Singleton
 
-from .driver.sqlite3 import get_app_engine, get_engine, get_test_engine
+from .driver.sqlite3 import get_test_engine
 from .model import Model
 
 
@@ -27,30 +32,32 @@ class _QueryProperty:
 
     def __get__(self, obj, type):
         try:
-            mapper = orm.class_mapper(type)
+            mapper = class_mapper(type)
             if mapper:
-                return type.query_class(mapper, session=self.db.session())
+                return Query([type]).with_session(self.db.session)
         except UnmappedClassError:
             return None
 
-
-class _Database(_Singleton):
+class DatabaseManager(_Singleton):
     engine = None
+    metadata = None
     session = None
 
-    def __init__(self, model=None, metadata=None, query_class=orm.Query):
-        self.Query = query_class
-        self.Model = self.make_declarative_base(model, metadata)
-
     @classmethod
     def test(cls):
-        return cls(get_test_engine())
+        cls.set_engine(get_test_engine())
 
-    def set_engine(self, engine):
-        self.engine = engine
-        self.session = scoped_session(
-            sessionmaker(autocommit=False, autoflush=False, bind=engine)
-        )
+    @classmethod
+    def set_engine(cls, engine):
+        cls.engine = engine
+        cls.metadata = MetaData(cls.engine)
+        cls.session = Session(autocommit=False, autoflush=False, bind=engine)
+
+class _Database():
+    def __init__(self, model=None, metadata=None, query_class=Query):
+        self.manager = DatabaseManager()
+        self.Query = query_class
+        self.Model = self.make_declarative_base(model, metadata)
 
     def make_declarative_base(self, model=None, metadata=None):
         if model == None:
@@ -59,26 +66,27 @@ class _Database(_Singleton):
             model = declarative_base(cls=model, name="Model", metadata=metadata)
         if metadata is not None and model.metadata is not metadata:
             model.metadata = metadata
+        else:
+            model.metadata = self.metadata
         if not getattr(model, "query_class", None):
             model.query_class = self.Query
         model.query = _QueryProperty(self)
         return model
 
+    @property
+    def engine(self):
+        return self.manager.engine
+
+    @property
+    def metadata(self):
+        return self.manager.metadata
+
+    @property
     def session(self):
-        return self.session
+        return self.manager.session
 
     def create_all(self):
-        self.Model.metadata.create_all(self.engine)
-
-
-class _CoreDatabase(_Database):
-    def __init__(self, engine=None):
-        super().__init__()
-        if self.engine == None:
-            if engine == None:
-                self.set_engine(get_engine())
-            else:
-                self.set_engine(engine)
+        self.metadata.create_all(self.engine)
 
 
 class BaseDatabase(_Database):
@@ -87,11 +95,12 @@ class BaseDatabase(_Database):
     アプリからデータベースを使うたい場合、このクラスを継承したクラスをアプリ内に定義します。
     """
 
-    def __init__(self, engine=None):
-        super().__init__()
-        if self.engine == None:
-            if engine == None:
-                package_name = inspect.getmodule(self.__class__).__package__
-                self.set_engine(get_app_engine(package_name))
-            else:
-                self.set_engine(engine)
+    def __init__(self, prefix=None, model=None, metadata=None, query_class=Query):
+        super().__init__(
+            model = model,
+            metadata = metadata,
+            query_class = query_class
+        )
+        if prefix == None:
+            prefix = _inspect.getmodule(self.__class__).__package__
+        self.Model.prefix = prefix
